@@ -58,7 +58,7 @@ class SingletonInjectable(Injectable[T]):
 
 
 @dataclass(repr=False, frozen=True, slots=True)
-class InjectionManager:
+class Manager:
     __container: dict[type, Injectable] = field(default_factory=dict, init=False)
 
     def get(self, __reference: type) -> Injectable:
@@ -67,7 +67,12 @@ class InjectionManager:
         try:
             return self.__container[cls]
         except KeyError as exc:
-            raise NoInjectable(f"No injectable for {cls.__name__}.") from exc
+            try:
+                name = cls.__name__
+            except AttributeError:  # pragma: no cover
+                name = repr(__reference)
+
+            raise NoInjectable(f"No injectable for {name}.") from exc
 
     def set_multiple(self, __references: Iterable[type], __injectable: Injectable):
         new_values = (
@@ -87,7 +92,18 @@ class InjectionManager:
         return __reference
 
 
-_manager = InjectionManager()
+class ManagerGetter:
+    __slots__ = ("__default",)
+
+    def __init__(self):
+        self.__default = self.__manager_factory()
+
+    def __call__(self) -> Manager:
+        return self.__default
+
+    @classmethod
+    def __manager_factory(cls) -> Manager:
+        return Manager()
 
 
 @dataclass(repr=False, frozen=True, slots=True)
@@ -109,9 +125,11 @@ class Dependencies:
 
     @classmethod
     def __resolver(cls, __signature: Signature) -> Iterator[tuple[str, Injectable]]:
+        manager = _get_manager()
+
         for name, parameter in __signature.parameters.items():
             try:
-                injectable_object = _manager.get(parameter.annotation)
+                injectable_object = manager.get(parameter.annotation)
             except NoInjectable:
                 continue
 
@@ -123,7 +141,7 @@ class Arguments(NamedTuple):
     kwargs: Mapping[str, Any]
 
 
-class Injector:
+class Binder:
     __slots__ = ("__callable", "__signature", "__dependencies")
 
     def __init__(self, __callable: Callable[..., Any], /):
@@ -188,11 +206,11 @@ class InjectDecorator:
 
     @classmethod
     def __decorator(cls, __function: Callable[..., Any], /) -> Callable[..., Any]:
-        injector = Injector(__function)
+        binder = Binder(__function)
 
         @wraps(__function)
         def wrapper(*args, **kwargs):
-            arguments = injector.bind(*args, **kwargs)
+            arguments = binder.bind(*args, **kwargs)
             return __function(*arguments.args, **arguments.kwargs)
 
         return wrapper
@@ -223,6 +241,7 @@ class InjectableDecorator:
             if auto_inject:
                 wp = inject(wp)
 
+            @lambda fn: fn()
             def iter_references():
                 if isinstance(wp, type):
                     yield wp
@@ -233,8 +252,8 @@ class InjectableDecorator:
                 yield from references
 
             injectable_object = self.__class(wp)
-            _manager.set_multiple(
-                iter_references(),
+            _get_manager().set_multiple(
+                iter_references,
                 injectable_object,
             )
 
@@ -243,21 +262,30 @@ class InjectableDecorator:
         return decorator(wrapped) if wrapped else decorator
 
 
+_get_manager = ManagerGetter()
+
 inject = InjectDecorator()
 injectable = InjectableDecorator(NewInjectable)
 singleton = InjectableDecorator(SingletonInjectable)
 
 
 def get_instance(reference: type[T]) -> T:
-    return _manager.get(reference).get_instance()
+    return _get_manager().get(reference).get_instance()
 
 
 del (
     Injectable,
     InjectableDecorator,
     InjectDecorator,
-    InjectionManager,
+    ManagerGetter,
     NewInjectable,
     SingletonInjectable,
     T,
 )
+
+__all__ = (
+    "get_instance",
+    "inject",
+    "injectable",
+    "singleton",
+)
